AddressDetails class

Address details.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

AddressDetails(String? streetNumber, String? streetName, String? streetType, String? deliveryService, String? buildingName, String? subBuilding)
const
AddressDetails.fromJson(Map<String, dynamic> json)
factory

Properties

buildingName → String?
A named locations that represents the premise. Usually a building name or number or collection of buildings with a common name or number. For example, Craven House.
final
deliveryService → String?
The delivery service. Post office box, bag number, or post office name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetName → String?
The street name. Just Drury in Drury Lane.
final
streetNumber → String?
The street number.
final
streetType → String?
The street type. For example, avenue, boulevard, road, or expressway.
final
subBuilding → String?
The first-order entity below a named building or location that represents the sub-premise. Usually a single building within a collection of buildings with a common name. Can be a flat, story, floor, room, or apartment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited