LinkDescription class

Annotations
  • @JsonSerializable.new()

Constructors

LinkDescription({required String href, required String rel, required String method, String? encType})
const
LinkDescription.fromJson(Map<String, dynamic> json)
factory

Properties

encType → String?
Encoding type.
final
hashCode → int
The hash code for this object.
no setterinherited
href → String
The complete target URL. To make the related call, combine the method with this URI Template-formatted link. For pre-processing, include the $, (, and ) characters. The href is the key HATEOAS component that links a completed call with a subsequent call.
final
method → String
The HTTP method required to make the related call. Possible values: GET, POST, PUT, DELETE, HEAD, CONNECT, OPTIONS, PATCH
final
rel → String
The link relation type, which serves as an ID for a link that unambiguously describes the semantics of the link. See Link Relations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited