AmountWithBreakdown class

Amount with breakdown.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

AmountWithBreakdown({required String currencyCode, required String value, AmountBreakdown? breakdown})
const
AmountWithBreakdown.fromJson(Map<String, dynamic> json)
factory

Properties

breakdown → AmountBreakdown?
The breakdown of the amount. Breakdown provides details such as total item amount, total tax amount, shipping, handling, insurance, and discounts, if any.
final
currencyCode → String
The three-character ISO-4217 currency code that identifies the currency.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The value, which might be:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited