AuthorizationWithAdditionalData class

Authorization with additional data.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

AuthorizationWithAdditionalData(ProcessorResponse processorResponse)
const
AuthorizationWithAdditionalData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
processorResponse → ProcessorResponse
The processor response for card transactions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited