Order class

An order.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Order({String? id, PaymentSource? paymentSource, String? intent, Payer? payer, List<PurchaseUnit>? purchaseUnits, String? status, String? createTime, String? updateTime, List<LinkDescription>? links})
const
Order.fromJson(Map<String, dynamic> json)
factory

Properties

createTime → String?
The date and time when the transaction occurred, in Internet date and time format
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the order.
final
intent → String?
The intent to either capture payment immediately or authorize a payment for an order after order creation.
final
An array of request-related HATEOAS links.
final
payer → Payer?
The customer who approves and pays for the order. The customer is also known as the payer.
final
paymentSource → PaymentSource?
The payment source used to fund the payment.
final
purchaseUnits → List<PurchaseUnit>?
An array of purchase units. Each purchase unit establishes a contract between a customer and merchant. Each purchase unit represents either a full or partial order that the customer intends to purchase from the merchant.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The order status.
final
updateTime → String?
The date and time when the transaction was last updated, in Internet date and time format
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited