Payer class

The payer of an order.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Payer({String? emailAddress, String? payerId})
const
Payer.fromJson(Map<String, dynamic> json)
factory

Properties

emailAddress → String?
The email address of the payer.
final
hashCode → int
The hash code for this object.
no setterinherited
payerId → String?
The PayPal-assigned ID for the payer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited