PaymentCollection class

A collection of payments

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

PaymentCollection({List<AuthorizationWithAdditionalData>? authorizations, List<Capture>? captures, List<Refund>? refunds})
const
PaymentCollection.fromJson(Map<String, dynamic> json)
factory

Properties

authorizations → List<AuthorizationWithAdditionalData>?
An array of authorized payments for a purchase unit. A purchase unit can have zero or more authorized payments.
final
captures → List<Capture>?
An array of captured payments for a purchase unit. A purchase unit can have zero or more captured payments.
final
hashCode → int
The hash code for this object.
no setterinherited
refunds → List<Refund>?
An array of refunds for a purchase unit. A purchase unit can have zero or more refunds.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited