Refund class

A refund.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Refund({String? status, RefundStatus? statusDetails, String? id, Money? amount, String? invoiceId, String? noteToPayer, String? sellerPayableBreakdown, String? createTime, String? updateTime, List<LinkDescription>? links})
const
Refund.fromJson(Map<String, dynamic> json)
factory

Properties

amount → Money?
The amount that the payee refunded to the payer.
final
createTime → String?
The date and time when the transaction occurred, in Internet date and time format
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The PayPal-generated ID for the refund.
final
invoiceId → String?
The API caller-provided external invoice number for this order. Appears in both the payer's transaction history and the emails that the payer receives.
final
An array of request-related HATEOAS links.
final
noteToPayer → String?
The reason for the refund. Appears in both the payer's transaction history and the emails that the payer receives.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerPayableBreakdown → String?
The breakdown of the refund.
final
status → String?
The status of the refund.
final
statusDetails → RefundStatus?
The details of the refund status.
final
updateTime → String?
The date and time when the transaction was last updated, in Internet date and time format
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited