SellerProtection class

Seller protection.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

SellerProtection({SellerProtectionStatus? status, List<DisputeCategoryValue>? disputeCategories})
const
SellerProtection.fromJson(Map<String, dynamic> json)
factory

Properties

disputeCategories → List<DisputeCategoryValue>?
An array of conditions that are covered for the transaction.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → SellerProtectionStatus?
Indicates whether the transaction is eligible for seller protection. For information, see PayPal Seller Protection for Merchants.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited