AmountWithBreakdown class

The breakdown details for the amount. Includes the gross, tax, fee, and shipping amounts.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

AmountWithBreakdown({required Money grossAmount, Money? totalItemAmount, Money? feeAmount, Money? shippingAmount, Money? taxAmount, Money? netAmount})
AmountWithBreakdown.fromJson(Map<String, dynamic> json)
factory

Properties

feeAmount → Money?
The fee details for the transaction.
final
grossAmount → Money
The amount for this transaction.
final
hashCode → int
The hash code for this object.
no setterinherited
netAmount → Money?
The net amount that the payee receives for this transaction in their PayPal account. The net amount is computed as gross_amount minus the paypal_fee.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAmount → Money?
The shipping amount for the transaction.
final
taxAmount → Money?
The tax amount for the transaction.
final
totalItemAmount → Money?
The item total for the transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited