ApplicationContext class

The application context, which customizes the payer experience during the subscription approval process with PayPal.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ApplicationContext({String? brandName, String? locale, ShippingPreference? shippingPreference, UserAction? userAction, PaymentMethod? paymentMethod, required String returnUrl, required String cancelUrl})
const
ApplicationContext.fromJson(Map<String, dynamic> json)
factory

Properties

brandName → String?
The label that overrides the business name in the PayPal account on the PayPal site.
final
cancelUrl → String
The URL where the customer is redirected after the customer cancels the payment.
final
hashCode → int
The hash code for this object.
no setterinherited
locale → String?
The BCP 47-formatted locale of pages that the PayPal payment experience shows. PayPal supports a five-character code. For example, da-DK, he-IL, id-ID, ja-JP, no-NO, pt-BR, ru-RU, sv-SE, th-TH, zh-CN, zh-HK, or zh-TW.
final
paymentMethod → PaymentMethod?
The customer and merchant payment preferences. Currently only PAYPAL payment method is supported.
final
returnUrl → String
The URL where the customer is redirected after the customer approves the payment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingPreference → ShippingPreference?
The location from which the shipping address is derived.
final
userAction → UserAction?
Configures the label name to Continue or Subscribe Now for subscription consent experience.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited