ShippingPreference enum

The location from which the shipping address is derived.

Inheritance
Available extensions

Values

getFromFile → const ShippingPreference

Get the customer-provided shipping address on the PayPal site.

noShipping → const ShippingPreference

Redacts the shipping address from the PayPal site. Recommended for digital goods.

setProvidedAddress → const ShippingPreference

Get the merchant-provided address. The customer cannot change this address on the PayPal site. If merchant does not pass an address, customer can choose the address on PayPal pages.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ShippingPreference>
A constant List of the values in this enum, in order of their declaration.