Transaction class

A transaction for a subscription

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Transaction({CaptureStatus? status, String? id, AmountWithBreakdown? amountWithBreakdown, Name? payerName, String? payerEmail, String? time})
Transaction.fromJson(Map<String, dynamic> json)
factory

Properties

amountWithBreakdown → AmountWithBreakdown?
The breakdown details for the amount. Includes the gross, tax, fee, and shipping amounts.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The PayPal-generated transaction ID.
final
payerEmail → String?
The email ID of the customer.
final
payerName → Name?
The name of the customer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CaptureStatus?
The status of the captured payment.
final
time → String?
The date and time when the transaction was processed, in Internet date and time format
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited